"""Unittests for letter structures."""
from unittest import TestCase
from unittest.mock import sentinel

from hermes.letter import Address, Letter


class LetterTest(TestCase):
    """Unittests for Letter structure."""

    def setUp(self):
        self.recipient = {
            'name': 'Kryton',
            'organization': 'Jupiter Mining Corp.',
            'street': None,
            'city': 'Red Dwarf',
            'state_or_province': None,
            'postal_code': 'JMC',
            'country_code': 'JU',
        }

    def test_init_empty(self):
        letter = Letter(sentinel.recipient, sentinel.file)
        self.assertEqual(letter.recipient, sentinel.recipient)
        self.assertEqual(letter.file, sentinel.file)

    def test_from_dict_missing_recipient(self):
        with self.assertRaises(ValueError):
            Letter.from_dict({'file': sentinel.file})

    def test_from_dict_missing_file(self):
        with self.assertRaises(ValueError):
            Letter.from_dict({'recipient': self.recipient})

    def test_from_dict_data(self):
        letter = Letter.from_dict({
            'recipient': self.recipient,
            'file': sentinel.file,
            'type': sentinel.type,
        })

        self.assertEqual(letter.recipient, Address(**self.recipient))
        self.assertEqual(letter.file, sentinel.file)
        self.assertEqual(letter.type, sentinel.type)

    def test_to_dict(self):
        letter = Letter.from_dict({
            'recipient': self.recipient,
            'file': sentinel.file,
            'type': sentinel.type,
        })
        self.assertEqual(letter.to_dict(), {
            'recipient': self.recipient,
            'file': sentinel.file,
            'type': sentinel.type,
        })
